==> haskell-quickcheck-io-0.2.0-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-io
version: 0.2.0
id: quickcheck-io-0.2.0-Gntr2T9Vy6n1IMUVJ9zBpG
key: quickcheck-io-0.2.0-Gntr2T9Vy6n1IMUVJ9zBpG
license: MIT
copyright: (c) 2013-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/quickcheck-io#readme
synopsis: Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.
category: Testing
abi: 0cb24f0a7d5776740fc367f3ec46ea05
exposed: True
exposed-modules:
    Test.QuickCheck.IO
hidden-modules: Paths_quickcheck_io
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-io-0.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-io-0.2.0
hs-libraries: HSquickcheck-io-0.2.0-Gntr2T9Vy6n1IMUVJ9zBpG
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-io-0.2.0-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-io
version: 0.2.0
id: quickcheck-io-0.2.0-39NZMZRO1eH86iwmEwHlbW
key: quickcheck-io-0.2.0-39NZMZRO1eH86iwmEwHlbW
license: MIT
copyright: (c) 2013-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/quickcheck-io#readme
synopsis: Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.
category: Testing
abi: 488eb960f733a66ff33dd19e3cf676c4
exposed: True
exposed-modules:
    Test.QuickCheck.IO
hidden-modules: Paths_quickcheck_io
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-io-0.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-io-0.2.0
hs-libraries: HSquickcheck-io-0.2.0-39NZMZRO1eH86iwmEwHlbW
depends:
    HUnit-1.6.0.0-CIh8yVnXF8fEfjQqWNmj9c
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
